.. _actionclasses:

Action Classes
==============

.. seealso:: It is important to note that each action has a `do_action()`
          method, which accepts no arguments.  This is the means by which all
          actions are executed.

* `Alias`_
* `Allocation`_
* `Close`_
* `DeleteIndices`_
* `DeleteSnapshots`_
* `ForceMerge`_
* `Open`_
* `Replicas`_
* `Snapshot`_


Alias
-----
.. autoclass:: curator.actions.Alias
   :members:

Allocation
----------
.. autoclass:: curator.actions.Allocation
  :members:

Close
-----
.. autoclass:: curator.actions.Close
  :members:

DeleteIndices
-------------
.. autoclass:: curator.actions.DeleteIndices
   :members:

DeleteSnapshots
---------------
.. autoclass:: curator.actions.DeleteSnapshots
  :members:

ForceMerge
----------
.. autoclass:: curator.actions.ForceMerge
  :members:

Open
----
.. autoclass:: curator.actions.Open
   :members:

Replicas
--------
.. autoclass:: curator.actions.Replicas
  :members:

Snapshot
--------
.. autoclass:: curator.actions.Snapshot
  :members:

Restore
-------
.. autoclass:: curator.actions.Restore
  :members:
